@@ -128,7 +128,7 @@ ebv_map <- function(filepath, datacubepath = NULL, entity=NULL, timestep=1, coun
   }
 
   #get properties
-  prop <- ebv_properties(filepath, datacubepath, verbose=verbose)
+  prop <- ebv_properties(filepath, datacubepath, verbose=FALSE)
 
   #timestep check
   #additional check because map only allows 1 timestep
@@ -196,6 +196,12 @@ ebv_map <- function(filepath, datacubepath = NULL, entity=NULL, timestep=1, coun
 
   subtitle <- paste0(metric_name, ' - ', label, ' (', timestep.nat, ')')
 
+  #add scenario name to subtitle if exists:
+  if('name' %in% names(prop@scenario)){
+    scenario_name <- prop@scenario$name
+    subtitle <- paste0(scenario_name, '\n', subtitle)
+  }
+
   #read the data necessary for the quantiles----
   data.all <- HDF5Array::HDF5Array(filepath = filepath, name = datacubepath,
                                    type = type.short)
@@ -304,7 +310,6 @@ ebv_map <- function(filepath, datacubepath = NULL, entity=NULL, timestep=1, coun
     palette <- 'RdYlBu'
   } else {
     palette <- 'YlGn'
-    direction <- direction * -1
   }
 
   #get x and y lab
@@ -330,27 +335,32 @@ ebv_map <- function(filepath, datacubepath = NULL, entity=NULL, timestep=1, coun
   }else{
     color_def <- ggplot2::scale_fill_fermenter(na.value=NA, palette = palette,
                                                breaks =  as.numeric(s),
-                                              label = signif(as.numeric(s), 3),
-                                              direction = direction,
-                                              name = paste(strwrap(
+                                               limits = c(s[1], s[classes+1]),
+                                               label = signif(as.numeric(s), 3),
+                                               direction = direction,
+                                               name = paste(strwrap(
                                                 units,
                                                 width = 10
-                                              ), collapse = "\n")
+                                               ), collapse = "\n")
                                               )
   }
 
   #plot with country outlines ----
   if (countries){
-    #prepare data
+
+    #get country data
     world_boundaries <- terra::vect(world_boundaries, geom='geometry', crs='EPSG:4326')
 
+    #project to correct CRS
     if(epsg != 4326){
       world_boundaries <- terra::project(world_boundaries, paste0('EPSG:', epsg))
     }
 
     #crop world_boundaries to extent
     extent <- terra::ext(data.raster)
-    world_boundaries <- terra::crop(world_boundaries, extent)
+    if(extent[1] > -180 || extent[2] < 180 || extent[3] > -90 || extent[4] < 83.64513){
+      world_boundaries <- terra::crop(world_boundaries, extent)
+    }
 
     print(
       ggplot2::ggplot() +
